@@ -2,7 +2,7 @@ package Storable::AMF0;
 use strict;
 use warnings;
 use Fcntl qw(:flock);
-our $VERSION = '0.78';
+our $VERSION = '0.79';
 use subs qw(freeze thaw);
 use Scalar::Util qw(refaddr reftype);    # for ref_circled
 
@@ -20,7 +20,7 @@ our %EXPORT_TAGS = (
           freeze thaw	dclone
           retrieve lock_retrieve lock_store lock_nstore store nstore
           ref_lost_memory ref_clear
-          deparse_amf
+          deparse_amf new_date perl_date
           )
     ]
 );
